@@ -1,6 +1,6 @@
 /***********************************************************************
  *  avra - Assembler for the Atmel AVR microcontroller series
- *  Copyright (C) 1998-1999 Jon Anders Haugum
+ *  Copyright (C) 1998-2000 Jon Anders Haugum
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@
 #include "device.h"
 
 const char *title = "avra %d.%d (%s)\n"
-                    "Copyright (C) 1998-1999 Jon Anders Haugum\n"
+                    "Copyright (C) 1998-2000 Jon Anders Haugum\n"
                     "   avra comes with NO WARRANTY, to the extent permitted by law.\n"
                     "   You may redistribute copies of avra under the terms\n"
                     "   of the GNU General Public License.\n"
@@ -125,14 +125,14 @@ void assemble(struct prog_info *pi)
 				        {
 					printf("Pass 2...\n");
 					parse_file(pi, (char *)pi->args->first_data->data, PASS_2);
+					close_out_files(pi);
+					write_map_file(pi);
 					if(pi->error_count)
 					        printf("Assembly aborted with %d errors and %d warnings\n", pi->error_count, pi->warning_count);
 					else if(pi->warning_count)
 					        printf("Assembly complete with no errors (%d warnings)\n", pi->warning_count);
 					else
 					        printf("Assembly complete with no errors\n");
-					close_out_files(pi);
-					write_map_file(pi);
 					}
 				}
 			}
@@ -145,13 +145,14 @@ void assemble(struct prog_info *pi)
 int load_arg_defines(struct prog_info *pi)
         {
 	int i;
-	char *expr;
+	char *expr, buff[256];
 	struct data_list *define;
 	struct label *label;
 
 	for(define = GET_ARG(pi->args, ARG_DEFINE); define; define = define->next)
 	        {
-		expr = get_next_token(define->data, TERM_EQUAL);
+		strcpy(buff, define->data);
+		expr = get_next_token(buff, TERM_EQUAL);
 		if(expr)
 		        {
 			if(!get_expr(pi, expr, &i))
@@ -160,9 +161,9 @@ int load_arg_defines(struct prog_info *pi)
 		else
 		        i = 1;
 		for(label = pi->first_constant; label; label = label->next)
-		        if(!nocase_strcmp(label->name, define->data))
+		        if(!nocase_strcmp(label->name, buff))
 			        {
-				printf("Error: Can't define symbol %s twice\n", (char *)define->data);
+				printf("Error: Can't define symbol %s twice\n", buff);
 				return(False);
 				}
 		label = malloc(sizeof(struct label));
@@ -177,13 +178,13 @@ int load_arg_defines(struct prog_info *pi)
 		else
 		        pi->first_constant = label;
 		pi->last_constant = label;
-		label->name = malloc(strlen(define->data) + 1);
+		label->name = malloc(strlen(buff) + 1);
 		if(!label->name)
 		        {
 			print_msg(pi, MSGTYPE_OUT_OF_MEM, NULL);
 			return(False);
 			}
-		strcpy(label->name, define->data);
+		strcpy(label->name, buff);
 		label->value = i;
 		}
 	return(True);
