@@ -1,6 +1,6 @@
 /***********************************************************************
  *  avra - Assembler for the Atmel AVR microcontroller series
- *  Copyright (C) 1998-1999 Jon Anders Haugum
+ *  Copyright (C) 1998-2000 Jon Anders Haugum
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,8 +26,8 @@
 #include <stdio.h>
 
 #define VERSION 0
-#define REVISION 4
-#define DATESTRING "24 March 1999"
+#define REVISION 5
+#define DATESTRING "4 January 2000"
 
 #define IS_HOR_SPACE(x) ((x == ' ') || (x == 9))
 #define IS_LABEL(x) (isalnum(x) || (x == '_'))
