@@ -1,6 +1,6 @@
 /***********************************************************************
  *  avra - Assembler for the Atmel AVR microcontroller series
- *  Copyright (C) 1998-1999 Jon Anders Haugum
+ *  Copyright (C) 1998-2000 Jon Anders Haugum
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -140,7 +140,7 @@ int parse_directive(struct prog_info *pi, int pass)
 				}
 			pi->dseg_addr += i;
 			if(pass == PASS_1)
-				pi->dseg_count++;
+				pi->dseg_count += i;
 			break;
 		case DIRECTIVE_CSEG:
 			pi->segment = SEGMENT_CODE;
@@ -215,10 +215,13 @@ int parse_directive(struct prog_info *pi, int pass)
 			while(next)
 				{
 				data = get_next_token(next, TERM_COMMA);
-				if(!get_expr(pi, next, &i))
-					return(False);
-				if((i < -32768) || (i > 65535))
-					print_msg(pi, MSGTYPE_ERROR, "Value %d is out of range (-32768 <= k <= 65535)", i);
+				if(pass == PASS_2)
+				  {
+				  if(!get_expr(pi, next, &i))
+				    return(False);
+				  if((i < -32768) || (i > 65535))
+				    print_msg(pi, MSGTYPE_ERROR, "Value %d is out of range (-32768 <= k <= 65535)", i);
+				  }
 				if(pi->segment == SEGMENT_EEPROM)
 					{
 					if(pass == PASS_2)
@@ -619,10 +622,13 @@ int parse_db(struct prog_info *pi, char *next, int pass)
 			}
 		else
 			{
-			if(!get_expr(pi, next, &i))
-				return(False);
-			if((i < -128) || (i > 255))
-				print_msg(pi, MSGTYPE_ERROR, "Value %d is out of range (-128 <= k <= 255)", i);
+			if(pass == PASS_2)
+			  {
+			  if(!get_expr(pi, next, &i))
+			    return(False);
+			  if((i < -128) || (i > 255))
+			    print_msg(pi, MSGTYPE_ERROR, "Value %d is out of range (-128 <= k <= 255)", i);
+			  }
 			count++;
 			write_db(pi, (char)i, &prev, count, pass);
 			}
