@@ -1,6 +1,6 @@
 /***********************************************************************
  *  avra - Assembler for the Atmel AVR microcontroller series
- *  Copyright (C) 1998-1999 Jon Anders Haugum
+ *  Copyright (C) 1998-2000 Jon Anders Haugum
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -81,6 +81,14 @@ int open_out_files(struct prog_info *pi, char *filename)
 
 void close_out_files(struct prog_info *pi)
 	{
+	if(pi->error_count == 0)
+		{
+		printf("Segment usage:\n"
+		       "   Code:   %7d words (%d bytes)\n"
+		       "   Data:   %7d bytes\n"
+		       "   EEPROM: %7d bytes\n",
+		       pi->cseg_count, pi->cseg_count * 2, pi->dseg_count, pi->eseg_count);
+		}
 	if(pi->hfi) close_hex_file(pi->hfi);
 	if(pi->eep_hfi) close_hex_file(pi->eep_hfi);
 	if(pi->list_file)
@@ -236,8 +244,3 @@ void write_obj_record(struct prog_info *pi, int address, int data)
 	else
 		fputc(0, pi->obj_file);
 	}
-
-
-
-
-
