@@ -1,6 +1,6 @@
 /***********************************************************************
  *  avra - Assembler for the Atmel AVR microcontroller series
- *  Copyright (C) 1998-1999 Jon Anders Haugum
+ *  Copyright (C) 1998-2000 Jon Anders Haugum
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -379,7 +379,7 @@ int parse_mnemonic(struct prog_info *pi, int pass)
 					}
 				else
 					{
-					if((i < -2048) || (i > 2047))
+					if(((i < -2048) || (i > 2047)) && (pi->device->flash_size != 4096))
 						print_msg(pi, MSGTYPE_ERROR, "Relative address out of range (-2048 <= k <= 2047)");
 					opcode = i & 0x0fff;
 					}
@@ -404,7 +404,7 @@ int parse_mnemonic(struct prog_info *pi, int pass)
 				i -= pi->cseg_addr + 1;
 				if((i < -64) || (i > 63))
 					print_msg(pi, MSGTYPE_ERROR, "Branch out of range (-64 <= k <= 63)");
-				opcode |= i << 3;
+				opcode |= (i & 0x7f) << 3;
 				}
 			else if(mnemonic <= MNEMONIC_MUL)
 				{
