@@ -1,6 +1,6 @@
 /***********************************************************************
  *  avra - Assembler for the Atmel AVR microcontroller series
- *  Copyright (C) 1998-1999 Jon Anders Haugum
+ *  Copyright (C) 1998-2000 Jon Anders Haugum
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -148,7 +148,7 @@ int parse_file(struct prog_info *pi, char *filename, int pass)
 
 int parse_line(struct prog_info *pi, char *line, int pass)
 	{
-	int ok, i, j, k, global_label = False;
+	int ok, i, j, k, global_label = False, textarea;
 	char temp[LINEBUFFER_LENGTH];
 	struct label *label = NULL;
 	struct macro_call *macro_call;
@@ -162,8 +162,12 @@ int parse_line(struct prog_info *pi, char *line, int pass)
 	strcpy(temp, &line[i]);
 
 	/* Calculate any expression inside a pair of {} */
-	for(i = 0, j = 0; temp[j] != '\0'; i++, j++)
+	for(i = 0, j = 0, textarea = False; temp[j] != '\0'; i++, j++)
 		{
+		if((temp[j] == '\'') || (temp[j] == '"'))
+			textarea = textarea ? False : True;
+		else if(!textarea && (temp[j] == ';'))
+			break;
 		if(temp[j] == '{')
 			{
 			k = ++j;
@@ -185,6 +189,7 @@ int parse_line(struct prog_info *pi, char *line, int pass)
 		else
 			pi->fi->scratch[i] = temp[j];
 		}
+	pi->fi->scratch[i] = '\0';
 
 	/* Detect the global keyword for global labels */
 	if(!nocase_strncmp(pi->fi->scratch, "global", 6) && IS_HOR_SPACE(pi->fi->scratch[6]))
